==> apache-dolphinscheduler-3.0.6-src.tar.gz: apache-dolphinscheduler-3.0.6-src/dolphinscheduler-ui/src/locales/en_US/resource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  file: {
    file_manage: 'File Manage',
    create_folder: 'Create Folder',
    create_file: 'Create File',
    upload_files: 'Upload Files',
    enter_keyword_tips: 'Please enter keyword',
    name: 'Name',
    user_name: 'Resource userName',
    whether_directory: 'Whether directory',
    file_name: 'File Name',
    description: 'Description',
    size: 'Size',
    update_time: 'Update Time',
    operation: 'Operation',
    edit: 'Edit',
    rename: 'Rename',
    download: 'Download',
    delete: 'Delete',
    yes: 'Yes',
    no: 'No',
    folder_name: 'Folder Name',
    enter_name_tips: 'Please enter name',
    enter_description_tips: 'Please enter description',
    enter_content_tips: 'Please enter the resource content',
    enter_suffix_tips: 'Please enter the suffix',
    duplicate_suffix_tips: 'Duplicate file suffix',
    file_format: 'File Format',
    file_content: 'File Content',
    delete_confirm: 'Delete?',
    confirm: 'Confirm',
    cancel: 'Cancel',
    success: 'Success',
    file_details: 'File Details',
    return: 'Return',
    save: 'Save'
  },
  udf: {
    udf_resources: 'UDF resources',
    create_folder: 'Create Folder',
    upload_udf_resources: 'Upload UDF Resources',
    udf_source_name: 'UDF Resource Name',
    user_name: 'Resource userName',
    whether_directory: 'Whether directory',
    file_name: 'File Name',
    file_size: 'File Size',
    description: 'Description',
    create_time: 'Create Time',
    update_time: 'Update Time',
    operation: 'Operation',
    yes: 'Yes',
    no: 'No',
    edit: 'Edit',
    download: 'Download',
    delete: 'Delete',
    delete_confirm: 'Delete?',
    success: 'Success',
    folder_name: 'Folder Name',
    upload: 'Upload',
    upload_files: 'Upload Files',
    file_upload: 'File Upload',
    enter_keyword_tips: 'Please enter keyword',
    enter_name_tips: 'Please enter name',
    enter_description_tips: 'Please enter description'
  },
  function: {
    udf_function: 'UDF Function',
    create_udf_function: 'Create UDF Function',
    edit_udf_function: 'Create UDF Function',
    udf_function_name: 'UDF Function Name',
    user_name: 'Resource userName',
    class_name: 'Class Name',
    type: 'Type',
    description: 'Description',
    jar_package: 'Jar Package',
    update_time: 'Update Time',
    operation: 'Operation',
    rename: 'Rename',
    edit: 'Edit',
    delete: 'Delete',
    success: 'Success',
    package_name: 'Package Name',
    udf_resources: 'UDF Resources',
    instructions: 'Instructions',
    upload_resources: 'Upload Resources',
    udf_resources_directory: 'UDF resources directory',
    delete_confirm: 'Delete?',
    enter_keyword_tips: 'Please enter keyword',
    enter_udf_unction_name_tips: 'Please enter a UDF function name',
    enter_package_name_tips: 'Please enter a Package name',
    enter_select_udf_resources_tips: 'Please select UDF resources',
    enter_select_udf_resources_directory_tips:
      'Please select UDF resources directory',
    enter_instructions_tips: 'Please enter a instructions',
    enter_name_tips: 'Please enter name',
    enter_description_tips: 'Please enter description',
    upload: 'Upload',
    upload_udf_resources: 'Upload UDF Resources'
  },
  task_group_option: {
    manage: 'Task group manage',
    option: 'Task group option',
    create: 'Create task group',
    edit: 'Edit task group',
    delete: 'Delete task group',
    view_queue: 'View the queue of the task group',
    switch_status: 'Switch status',
    code: 'Task group code',
    name: 'Task group name',
    project_name: 'Project name',
    resource_pool_size: 'Resource pool size',
    resource_used_pool_size: 'Used resource',
    desc: 'Task group desc',
    status: 'Task group status',
    enable_status: 'Enable',
    disable_status: 'Disable',
    please_enter_name: 'Please enter task group name',
    please_enter_desc: 'Please enter task group description',
    please_enter_resource_pool_size:
      'Please enter task group resource pool size',
    positive_integer_tips: 'should be a positive integer',
    please_select_project: 'Please select a project',
    create_time: 'Create time',
    update_time: 'Update time',
    actions: 'Actions',
    please_enter_keywords: 'Please enter keywords'
  },
  task_group_queue: {
    actions: 'Actions',
    task_name: 'Task name',
    task_group_name: 'Task group name',
    project_name: 'Project name',
    task_instance_name: 'Task instance',
    workflow_instance_name: 'Workflow instance',
    queue: 'Task group queue',
    priority: 'Priority',
    priority_be_a_number:
      'The priority of the task group queue should be a positive number',
    force_starting_status: 'Starting status',
    in_queue: 'In queue',
    task_status: 'Task status',
    view: 'View task group queue',
    the_status_of_waiting: 'Waiting into the queue',
    the_status_of_queuing: 'Queuing',
    the_status_of_releasing: 'Released',
    modify_priority: 'Edit the priority',
    start_task: 'Start the task',
    priority_not_empty: 'The value of priority can not be empty',
    priority_must_be_number: 'The value of priority should be number',
    please_select_task_name: 'Please select a task name',
    create_time: 'Create time',
    update_time: 'Update time',
    edit_priority: 'Edit the task priority'
  }
}

==> apache-dolphinscheduler-3.3.1-src.tar.gz: apache-dolphinscheduler-3.3.1-src/dolphinscheduler-ui/src/locales/en_US/resource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  file: {
    file_manage: 'File Manage',
    create_folder: 'Create Folder',
    create_file: 'Create File',
    upload_files: 'Upload Files',
    enter_keyword_tips: 'Please enter keyword',
    name: 'Name',
    user_name: 'Resource userName',
    tenant_name: 'Resource tenantName',
    whether_directory: 'Whether directory',
    file_name: 'File Name',
    description: 'Description',
    size: 'Size',
    create_time: 'Create Time',
    update_time: 'Update Time',
    operation: 'Operation',
    edit: 'Edit',
    reupload: 'ReUpload File',
    rename: 'Rename',
    download: 'Download',
    delete: 'Delete',
    yes: 'Yes',
    no: 'No',
    folder_name: 'Folder Name',
    enter_name_tips: 'Please enter name',
    enter_description_tips: 'Please enter description',
    enter_content_tips: 'Please enter the resource content',
    enter_suffix_tips: 'Please enter the suffix',
    duplicate_suffix_tips: 'Duplicate file suffix',
    file_format: 'File Format',
    file_content: 'File Content',
    delete_confirm: 'Delete?',
    confirm: 'Confirm',
    cancel: 'Cancel',
    success: 'Success',
    file_details: 'File Details',
    return: 'Return',
    save: 'Save'
  },
  function: {
    user_name: 'Resource userName',
    class_name: 'Class Name',
    type: 'Type',
    description: 'Description',
    jar_package: 'Jar Package',
    update_time: 'Update Time',
    operation: 'Operation',
    rename: 'Rename',
    edit: 'Edit',
    delete: 'Delete',
    success: 'Success',
    package_name: 'Package Name',
    instructions: 'Instructions',
    upload_resources: 'Upload Resources',
    delete_confirm: 'Delete?',
    enter_keyword_tips: 'Please enter keyword',
    enter_package_name_tips: 'Please enter a Package name',
    enter_instructions_tips: 'Please enter a instructions',
    enter_name_tips: 'Please enter name',
    enter_description_tips: 'Please enter description',
    upload: 'Upload'
  },
  task_group_option: {
    manage: 'Task group manage',
    option: 'Task group option',
    create: 'Create task group',
    edit: 'Edit task group',
    delete: 'Delete task group',
    view_queue: 'View the queue of the task group',
    switch_status: 'Switch status',
    code: 'Task group code',
    name: 'Task group name',
    project_name: 'Project name',
    resource_pool_size: 'Resource pool size',
    resource_used_pool_size: 'Used resource',
    desc: 'Task group desc',
    status: 'Task group status',
    enable_status: 'Enable',
    disable_status: 'Disable',
    please_enter_name: 'Please enter task group name',
    please_enter_desc: 'Please enter task group description',
    please_enter_resource_pool_size:
      'Please enter task group resource pool size',
    positive_integer_tips: 'should be a positive integer',
    please_select_project: 'Please select a project',
    create_time: 'Create time',
    update_time: 'Update time',
    actions: 'Actions',
    please_enter_keywords: 'Please enter keywords'
  },
  task_group_queue: {
    actions: 'Actions',
    task_name: 'Task name',
    task_group_name: 'Task group name',
    project_name: 'Project name',
    task_instance_name: 'Task instance',
    workflow_instance_name: 'Workflow instance',
    queue: 'Task group queue',
    priority: 'Priority',
    priority_be_a_number:
      'The priority of the task group queue should be a positive number',
    force_starting_status: 'Starting status',
    in_queue: 'In queue',
    task_status: 'Task status',
    view: 'View task group queue',
    the_status_of_waiting: 'Waiting into the queue',
    the_status_of_queuing: 'Queuing',
    the_status_of_releasing: 'Released',
    modify_priority: 'Edit the priority',
    start_task: 'Start the task',
    priority_not_empty: 'The value of priority can not be empty',
    priority_must_be_number: 'The value of priority should be number',
    please_select_task_name: 'Please select a task name',
    create_time: 'Create time',
    update_time: 'Update time',
    edit_priority: 'Edit the task priority'
  }
}
